////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  mf_1_1_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "mf_1_1_0.h"
#include "parametersetmanager.h"

MF_1_1_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mf11_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "anchor_picking") == 0)
    {
        __result = anchor_picking.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mf11_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "anchor_picking") == 0)
    {
        __result = anchor_picking.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mf11_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // top
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("top", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetInfo(&__path[__pos], __info);
    }

    // anchor_picking
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("anchor_picking", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "anchor_picking") == 0)
    {
        __result = anchor_picking.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mf11_rgn_dataType::topStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfsr") == 0)
    {
        ParameterUtils::DoubleToString((double)enable_mfsr, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "num_of_frames") == 0)
    {
        ParameterUtils::DoubleToString((double)num_of_frames, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_luma") == 0)
    {
        ParameterUtils::DoubleToString((double)pre_filtering_strength_luma, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_chroma") == 0)
    {
        ParameterUtils::DoubleToString((double)pre_filtering_strength_chroma, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool mf11_rgn_dataType::topStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfsr") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable_mfsr = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "num_of_frames") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            num_of_frames = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_luma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            pre_filtering_strength_luma = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_chroma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            pre_filtering_strength_chroma = (float)dblValue; 
        }
    }

    return __result;
}

bool mf11_rgn_dataType::topStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_mfsr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_mfsr", ParameterParserDataType::UInt32, (double)enable_mfsr, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable_mfsr") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)enable_mfsr, 0));
    }

    // num_of_frames
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("num_of_frames", ParameterParserDataType::UInt32, (double)num_of_frames, 0));
    }
    else if (PARAMETER_STRCMP(__name, "num_of_frames") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)num_of_frames, 0));
    }

    // pre_filtering_strength_luma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_filtering_strength_luma", ParameterParserDataType::UInt32, (double)pre_filtering_strength_luma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_luma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)pre_filtering_strength_luma, 0));
    }

    // pre_filtering_strength_chroma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_filtering_strength_chroma", ParameterParserDataType::UInt32, (double)pre_filtering_strength_chroma, 0));
    }
    else if (PARAMETER_STRCMP(__name, "pre_filtering_strength_chroma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)pre_filtering_strength_chroma, 0));
    }

    return __result;
}

bool mf11_rgn_dataType::anchor_pickingStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        ParameterUtils::DoubleToString((double)mode, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "anchor_time_range") == 0)
    {
        ParameterUtils::DoubleToString((double)anchor_time_range, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "brightness_tolerance") == 0)
    {
        ParameterUtils::DoubleToString((double)brightness_tolerance, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "remove_expected_bad_images") == 0)
    {
        ParameterUtils::DoubleToString((double)remove_expected_bad_images, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "min_histogram_bin") == 0)
    {
        ParameterUtils::DoubleToString((double)min_histogram_bin, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_histogram_bin") == 0)
    {
        ParameterUtils::DoubleToString((double)max_histogram_bin, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool mf11_rgn_dataType::anchor_pickingStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            mode = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "anchor_time_range") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            anchor_time_range = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "brightness_tolerance") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            brightness_tolerance = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "remove_expected_bad_images") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            remove_expected_bad_images = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "min_histogram_bin") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_histogram_bin = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_histogram_bin") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_histogram_bin = (float)dblValue; 
        }
    }

    return __result;
}

bool mf11_rgn_dataType::anchor_pickingStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mode", ParameterParserDataType::UInt32, (double)mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)mode, 0));
    }

    // anchor_time_range
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("anchor_time_range", ParameterParserDataType::UInt32, (double)anchor_time_range, 0));
    }
    else if (PARAMETER_STRCMP(__name, "anchor_time_range") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)anchor_time_range, 0));
    }

    // brightness_tolerance
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("brightness_tolerance", ParameterParserDataType::UInt32, (double)brightness_tolerance, 0));
    }
    else if (PARAMETER_STRCMP(__name, "brightness_tolerance") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)brightness_tolerance, 0));
    }

    // remove_expected_bad_images
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("remove_expected_bad_images", ParameterParserDataType::UInt32, (double)remove_expected_bad_images, 0));
    }
    else if (PARAMETER_STRCMP(__name, "remove_expected_bad_images") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)remove_expected_bad_images, 0));
    }

    // min_histogram_bin
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_histogram_bin", ParameterParserDataType::UInt32, (double)min_histogram_bin, 0));
    }
    else if (PARAMETER_STRCMP(__name, "min_histogram_bin") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)min_histogram_bin, 0));
    }

    // max_histogram_bin
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_histogram_bin", ParameterParserDataType::UInt32, (double)max_histogram_bin, 0));
    }
    else if (PARAMETER_STRCMP(__name, "max_histogram_bin") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)max_histogram_bin, 0));
    }

    return __result;
}

bool mod_mf11_cct_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "mf11_rgn_data") == 0)
    {
        __result = mf11_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_cct_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "mf11_rgn_data") == 0)
    {
        __result = mf11_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_cct_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // cct_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cct_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetInfo(&__path[__pos], __info);
    }

    // mf11_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mf11_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "mf11_rgn_data") == 0)
    {
        __result = mf11_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_aec_dataType::aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_cct_data") == 0)
    {
        if (__index < mod_mf11_cct_dataCount)
        {
            __result = mod_mf11_cct_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_aec_dataType::aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_cct_data") == 0)
    {
        if (__index < mod_mf11_cct_dataCount)
        {
            __result = mod_mf11_cct_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_aec_dataType::aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_cct_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_cct_data", ParameterParserDataType::Structure, true, false, mod_mf11_cct_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_cct_data") == 0)
    {
        if (__index < mod_mf11_cct_dataCount)
        {
            __result = mod_mf11_cct_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_cct_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_aec_data") == 0)
    {
        if (__index < mod_mf11_aec_dataCount)
        {
            __result = mod_mf11_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_aec_data") == 0)
    {
        if (__index < mod_mf11_aec_dataCount)
        {
            __result = mod_mf11_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_aec_data", ParameterParserDataType::Structure, true, false, mod_mf11_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_aec_data") == 0)
    {
        if (__index < mod_mf11_aec_dataCount)
        {
            __result = mod_mf11_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_aec_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_hdr_aec_data") == 0)
    {
        if (__index < mod_mf11_hdr_aec_dataCount)
        {
            __result = mod_mf11_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_hdr_aec_data") == 0)
    {
        if (__index < mod_mf11_hdr_aec_dataCount)
        {
            __result = mod_mf11_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_mf11_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_hdr_aec_data") == 0)
    {
        if (__index < mod_mf11_hdr_aec_dataCount)
        {
            __result = mod_mf11_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // pre_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_drc_gain_data") == 0)
    {
        if (__index < mod_mf11_drc_gain_dataCount)
        {
            __result = mod_mf11_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_drc_gain_data") == 0)
    {
        if (__index < mod_mf11_drc_gain_dataCount)
        {
            __result = mod_mf11_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_mf11_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_drc_gain_data") == 0)
    {
        if (__index < mod_mf11_drc_gain_dataCount)
        {
            __result = mod_mf11_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_drc_gain_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "post_scale_ratio_trigger") == 0)
    {
        __result = post_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "post_scale_ratio_data") == 0)
    {
        __result = post_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "post_scale_ratio_trigger") == 0)
    {
        __result = post_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "post_scale_ratio_data") == 0)
    {
        __result = post_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // post_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("post_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "post_scale_ratio_trigger") == 0)
    {
        __result = post_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // post_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("post_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "post_scale_ratio_data") == 0)
    {
        __result = post_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::post_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_pre_scale_ratio_dataCount)
        {
            __result = mod_mf11_pre_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::post_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_pre_scale_ratio_dataCount)
        {
            __result = mod_mf11_pre_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_post_scale_ratio_dataType::post_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_pre_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_mf11_pre_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_pre_scale_ratio_dataCount)
        {
            __result = mod_mf11_pre_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_pre_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_zoom_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::lens_zoom_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_post_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_post_scale_ratio_dataCount)
        {
            __result = mod_mf11_post_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::lens_zoom_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_post_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_post_scale_ratio_dataCount)
        {
            __result = mod_mf11_post_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_lens_zoom_dataType::lens_zoom_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_post_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_post_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_mf11_post_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_post_scale_ratio_data") == 0)
    {
        if (__index < mod_mf11_post_scale_ratio_dataCount)
        {
            __result = mod_mf11_post_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_post_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_posn_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::lens_posn_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_lens_zoom_data") == 0)
    {
        if (__index < mod_mf11_lens_zoom_dataCount)
        {
            __result = mod_mf11_lens_zoom_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::lens_posn_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_lens_zoom_data") == 0)
    {
        if (__index < mod_mf11_lens_zoom_dataCount)
        {
            __result = mod_mf11_lens_zoom_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_mf11_lens_posn_dataType::lens_posn_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_lens_zoom_data", ParameterParserDataType::Structure, true, false, mod_mf11_lens_zoom_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_lens_zoom_data") == 0)
    {
        if (__index < mod_mf11_lens_zoom_dataCount)
        {
            __result = mod_mf11_lens_zoom_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_lens_zoom_dataCount));
        }
    }

    return __result;
}

bool chromatix_mf11_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_lens_posn_data") == 0)
    {
        if (__index < mod_mf11_lens_posn_dataCount)
        {
            __result = mod_mf11_lens_posn_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_mf11_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_mf11_lens_posn_data") == 0)
    {
        if (__index < mod_mf11_lens_posn_dataCount)
        {
            __result = mod_mf11_lens_posn_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_mf11_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_mf11_lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_mf11_lens_posn_data", ParameterParserDataType::Structure, true, false, mod_mf11_lens_posn_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_mf11_lens_posn_data") == 0)
    {
        if (__index < mod_mf11_lens_posn_dataCount)
        {
            __result = mod_mf11_lens_posn_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_mf11_lens_posn_dataCount));
        }
    }

    return __result;
}

bool chromatix_mf11_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mfsr_disable_gain") == 0)
    {
        ParameterUtils::DoubleToString((double)mfsr_disable_gain, __value, __size);
        __result = true;
    }

    return __result;
}

bool chromatix_mf11_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mfsr_disable_gain") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            mfsr_disable_gain = (float)dblValue; 
        }
    }

    return __result;
}

bool chromatix_mf11_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mfsr_disable_gain
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mfsr_disable_gain", ParameterParserDataType::Float, (double)mfsr_disable_gain));
    }
    else if (PARAMETER_STRCMP(__name, "mfsr_disable_gain") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)mfsr_disable_gain));
    }

    return __result;
}

bool chromatix_mf11Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_reserve") == 0)
    {
        __result = chromatix_mf11_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_core") == 0)
    {
        __result = chromatix_mf11_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_mf11Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_reserve") == 0)
    {
        __result = chromatix_mf11_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_core") == 0)
    {
        __result = chromatix_mf11_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_mf11Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // dynamic_enable_triggers
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dynamic_enable_triggers", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetInfo(&__path[__pos], __info);
    }

    // chromatix_mf11_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_mf11_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_reserve") == 0)
    {
        __result = chromatix_mf11_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_mf11_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_mf11_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_mf11_core") == 0)
    {
        __result = chromatix_mf11_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_mf11Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        ParameterUtils::DoubleToString((double)enable_mfnr, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_mf11Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable_mfnr = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_mf11Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_mfnr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_mfnr", ParameterParserDataType::Int32, (double)enable_mfnr, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enable_mfnr, 0));
    }

    return __result;
}

bool chromatix_mf11Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_mf11Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_mf11Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_mf11Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_mf11Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_mf11Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_mf11Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_mf11Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_mf11Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 8));
    }

    return __result;
}

bool chromatix_mf11Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_mf11Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_mf11Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        __result = enable_mfnr.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        __result = enable_mfnr.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_mfnr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_mfnr", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_mfnr") == 0)
    {
        __result = enable_mfnr.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::enable_mfnrStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_control_var, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_mode, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::enable_mfnrStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_control_var = (ispglobalelements::control_var_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_mode = (ispglobalelements::hyst_direction)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_mf11Type::dynamic_enable_triggersStruct::enable_mfnrStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Int32, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enable, 0));
    }

    // hyst_control_var
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_control_var", ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }

    // hyst_mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_mode", ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }

    // hyst_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_mf11Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_cct):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_cct;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lens_position):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lens_position;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_post_scale_ratio):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_post_scale_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio):
            enumValue = chromatix_mf11Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_mf11Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_mf11TypeClass::chromatix_mf11TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_mf11_reserve);
    PARAMETER_INITIALIZE(chromatix_mf11_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_mf11TypeClass::chromatix_mf11TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_mf11_reserve);
    PARAMETER_INITIALIZE(chromatix_mf11_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_mf11TypeClass::~chromatix_mf11TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_mf11TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "mf11_sw")) == 0)
    {
        name = "mf11_sw";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mf11_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mf11_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(top);
    PARAMETER_INITIALIZE(anchor_picking);

    result = top.Load(entry, alignment);
    if (result)
    {
        result = anchor_picking.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mf11_rgn_dataType_topStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mf11_rgn_dataType::topStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_mfsr);
    PARAMETER_INITIALIZE(num_of_frames);
    PARAMETER_INITIALIZE(pre_filtering_strength_luma);
    PARAMETER_INITIALIZE(pre_filtering_strength_chroma);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable_mfsr, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, num_of_frames, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, pre_filtering_strength_luma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, pre_filtering_strength_chroma, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mf11_rgn_dataType_anchor_pickingStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mf11_rgn_dataType::anchor_pickingStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mode);
    PARAMETER_INITIALIZE(anchor_time_range);
    PARAMETER_INITIALIZE(brightness_tolerance);
    PARAMETER_INITIALIZE(remove_expected_bad_images);
    PARAMETER_INITIALIZE(min_histogram_bin);
    PARAMETER_INITIALIZE(max_histogram_bin);

    SYMBOL_TABLE_ENTRY_READ(entry, result, mode, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, anchor_time_range, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, brightness_tolerance, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, remove_expected_bad_images, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, min_histogram_bin, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_histogram_bin, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_cct_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_cct_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(cct_trigger);
    PARAMETER_INITIALIZE(mf11_rgn_data);

    result = cct_trigger.Load(entry, alignment);
    if (result)
    {
        result = mf11_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(aec_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_aec_dataType::aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_cct_data);


    // Reading Array mod_mf11_cct_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_cct_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_cct_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_cct_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_cct_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_cct_dataCount, file, line);
            if (mod_mf11_cct_dataDupInfo != nullptr && mod_mf11_cct_dataDupInfo->Object != nullptr)
            {
                mod_mf11_cct_data = (mod_mf11_cct_dataType*)mod_mf11_cct_dataDupInfo->Object;
                if (mod_mf11_cct_data == nullptr)
                {
                    if (mod_mf11_cct_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_cct_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_cct_dataDupInfo->File, mod_mf11_cct_dataDupInfo->Line, mod_mf11_cct_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_cct_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_cct_dataDupInfo->Line, mod_mf11_cct_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_cct_data == nullptr)
            {
                if (result && mod_mf11_cct_dataCount > 0)
                {
                    mod_mf11_cct_data = PARAMETER_NEW mod_mf11_cct_dataType[mod_mf11_cct_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_cct_data, mod_mf11_cct_dataCount, file, line);
                }
                if (!result || mod_mf11_cct_data == nullptr)
                {
                    if (mod_mf11_cct_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_cct_data\n");
                    }
                    mod_mf11_cct_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_cct_dataCount; i++)
                {
                    result = mod_mf11_cct_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_cct_data == nullptr)
        {
            mod_mf11_cct_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_aec_data);


    // Reading Array mod_mf11_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_aec_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_aec_dataCount, file, line);
            if (mod_mf11_aec_dataDupInfo != nullptr && mod_mf11_aec_dataDupInfo->Object != nullptr)
            {
                mod_mf11_aec_data = (mod_mf11_aec_dataType*)mod_mf11_aec_dataDupInfo->Object;
                if (mod_mf11_aec_data == nullptr)
                {
                    if (mod_mf11_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_aec_dataDupInfo->File, mod_mf11_aec_dataDupInfo->Line, mod_mf11_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_aec_dataDupInfo->Line, mod_mf11_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_aec_data == nullptr)
            {
                if (result && mod_mf11_aec_dataCount > 0)
                {
                    mod_mf11_aec_data = PARAMETER_NEW mod_mf11_aec_dataType[mod_mf11_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_aec_data, mod_mf11_aec_dataCount, file, line);
                }
                if (!result || mod_mf11_aec_data == nullptr)
                {
                    if (mod_mf11_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_aec_data\n");
                    }
                    mod_mf11_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_aec_dataCount; i++)
                {
                    result = mod_mf11_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_aec_data == nullptr)
        {
            mod_mf11_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_hdr_aec_data);


    // Reading Array mod_mf11_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_hdr_aec_dataCount, file, line);
            if (mod_mf11_hdr_aec_dataDupInfo != nullptr && mod_mf11_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_mf11_hdr_aec_data = (mod_mf11_hdr_aec_dataType*)mod_mf11_hdr_aec_dataDupInfo->Object;
                if (mod_mf11_hdr_aec_data == nullptr)
                {
                    if (mod_mf11_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_hdr_aec_dataDupInfo->File, mod_mf11_hdr_aec_dataDupInfo->Line, mod_mf11_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_hdr_aec_dataDupInfo->Line, mod_mf11_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_hdr_aec_data == nullptr)
            {
                if (result && mod_mf11_hdr_aec_dataCount > 0)
                {
                    mod_mf11_hdr_aec_data = PARAMETER_NEW mod_mf11_hdr_aec_dataType[mod_mf11_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_hdr_aec_data, mod_mf11_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_mf11_hdr_aec_data == nullptr)
                {
                    if (mod_mf11_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_hdr_aec_data\n");
                    }
                    mod_mf11_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_hdr_aec_dataCount; i++)
                {
                    result = mod_mf11_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_hdr_aec_data == nullptr)
        {
            mod_mf11_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_pre_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(pre_scale_ratio_trigger);
    PARAMETER_INITIALIZE(pre_scale_ratio_data);

    result = pre_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = pre_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_drc_gain_data);


    // Reading Array mod_mf11_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_drc_gain_dataCount, file, line);
            if (mod_mf11_drc_gain_dataDupInfo != nullptr && mod_mf11_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_mf11_drc_gain_data = (mod_mf11_drc_gain_dataType*)mod_mf11_drc_gain_dataDupInfo->Object;
                if (mod_mf11_drc_gain_data == nullptr)
                {
                    if (mod_mf11_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_drc_gain_dataDupInfo->File, mod_mf11_drc_gain_dataDupInfo->Line, mod_mf11_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_drc_gain_dataDupInfo->Line, mod_mf11_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_drc_gain_data == nullptr)
            {
                if (result && mod_mf11_drc_gain_dataCount > 0)
                {
                    mod_mf11_drc_gain_data = PARAMETER_NEW mod_mf11_drc_gain_dataType[mod_mf11_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_drc_gain_data, mod_mf11_drc_gain_dataCount, file, line);
                }
                if (!result || mod_mf11_drc_gain_data == nullptr)
                {
                    if (mod_mf11_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_drc_gain_data\n");
                    }
                    mod_mf11_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_drc_gain_dataCount; i++)
                {
                    result = mod_mf11_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_drc_gain_data == nullptr)
        {
            mod_mf11_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_post_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_post_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(post_scale_ratio_trigger);
    PARAMETER_INITIALIZE(post_scale_ratio_data);

    result = post_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = post_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_post_scale_ratio_dataType_post_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_post_scale_ratio_dataType::post_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_pre_scale_ratio_data);


    // Reading Array mod_mf11_pre_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_pre_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_pre_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_pre_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_pre_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_pre_scale_ratio_dataCount, file, line);
            if (mod_mf11_pre_scale_ratio_dataDupInfo != nullptr && mod_mf11_pre_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_mf11_pre_scale_ratio_data = (mod_mf11_pre_scale_ratio_dataType*)mod_mf11_pre_scale_ratio_dataDupInfo->Object;
                if (mod_mf11_pre_scale_ratio_data == nullptr)
                {
                    if (mod_mf11_pre_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_pre_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_pre_scale_ratio_dataDupInfo->File, mod_mf11_pre_scale_ratio_dataDupInfo->Line, mod_mf11_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_pre_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_pre_scale_ratio_dataDupInfo->Line, mod_mf11_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_pre_scale_ratio_data == nullptr)
            {
                if (result && mod_mf11_pre_scale_ratio_dataCount > 0)
                {
                    mod_mf11_pre_scale_ratio_data = PARAMETER_NEW mod_mf11_pre_scale_ratio_dataType[mod_mf11_pre_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_pre_scale_ratio_data, mod_mf11_pre_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_mf11_pre_scale_ratio_data == nullptr)
                {
                    if (mod_mf11_pre_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_pre_scale_ratio_data\n");
                    }
                    mod_mf11_pre_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_pre_scale_ratio_dataCount; i++)
                {
                    result = mod_mf11_pre_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_pre_scale_ratio_data == nullptr)
        {
            mod_mf11_pre_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_lens_zoom_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_zoom_trigger);
    PARAMETER_INITIALIZE(lens_zoom_data);

    result = lens_zoom_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_zoom_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_lens_zoom_dataType::lens_zoom_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_post_scale_ratio_data);


    // Reading Array mod_mf11_post_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_post_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_post_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_post_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_post_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_post_scale_ratio_dataCount, file, line);
            if (mod_mf11_post_scale_ratio_dataDupInfo != nullptr && mod_mf11_post_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_mf11_post_scale_ratio_data = (mod_mf11_post_scale_ratio_dataType*)mod_mf11_post_scale_ratio_dataDupInfo->Object;
                if (mod_mf11_post_scale_ratio_data == nullptr)
                {
                    if (mod_mf11_post_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_post_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_post_scale_ratio_dataDupInfo->File, mod_mf11_post_scale_ratio_dataDupInfo->Line, mod_mf11_post_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_post_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_post_scale_ratio_dataDupInfo->Line, mod_mf11_post_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_post_scale_ratio_data == nullptr)
            {
                if (result && mod_mf11_post_scale_ratio_dataCount > 0)
                {
                    mod_mf11_post_scale_ratio_data = PARAMETER_NEW mod_mf11_post_scale_ratio_dataType[mod_mf11_post_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_post_scale_ratio_data, mod_mf11_post_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_mf11_post_scale_ratio_data == nullptr)
                {
                    if (mod_mf11_post_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_post_scale_ratio_data\n");
                    }
                    mod_mf11_post_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_post_scale_ratio_dataCount; i++)
                {
                    result = mod_mf11_post_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_post_scale_ratio_data == nullptr)
        {
            mod_mf11_post_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_lens_posn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_posn_trigger);
    PARAMETER_INITIALIZE(lens_posn_data);

    result = lens_posn_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_posn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_mf11_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_mf11_lens_posn_dataType::lens_posn_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_lens_zoom_data);


    // Reading Array mod_mf11_lens_zoom_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_lens_zoom_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_lens_zoom_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_lens_zoom_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_lens_zoom_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_lens_zoom_dataCount, file, line);
            if (mod_mf11_lens_zoom_dataDupInfo != nullptr && mod_mf11_lens_zoom_dataDupInfo->Object != nullptr)
            {
                mod_mf11_lens_zoom_data = (mod_mf11_lens_zoom_dataType*)mod_mf11_lens_zoom_dataDupInfo->Object;
                if (mod_mf11_lens_zoom_data == nullptr)
                {
                    if (mod_mf11_lens_zoom_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_lens_zoom_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_lens_zoom_dataDupInfo->File, mod_mf11_lens_zoom_dataDupInfo->Line, mod_mf11_lens_zoom_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_lens_zoom_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_lens_zoom_dataDupInfo->Line, mod_mf11_lens_zoom_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_lens_zoom_data == nullptr)
            {
                if (result && mod_mf11_lens_zoom_dataCount > 0)
                {
                    mod_mf11_lens_zoom_data = PARAMETER_NEW mod_mf11_lens_zoom_dataType[mod_mf11_lens_zoom_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_lens_zoom_data, mod_mf11_lens_zoom_dataCount, file, line);
                }
                if (!result || mod_mf11_lens_zoom_data == nullptr)
                {
                    if (mod_mf11_lens_zoom_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_lens_zoom_data\n");
                    }
                    mod_mf11_lens_zoom_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_lens_zoom_dataCount; i++)
                {
                    result = mod_mf11_lens_zoom_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_lens_zoom_data == nullptr)
        {
            mod_mf11_lens_zoom_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_mf11_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_mf11_lens_posn_data);


    // Reading Array mod_mf11_lens_posn_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_mf11_lens_posn_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_mf11_lens_posn_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_mf11_lens_posn_dataID = pointerEntry->ID;
            DupObjInfo* mod_mf11_lens_posn_dataDupInfo = pointerEntry->GetDupObject(mod_mf11_lens_posn_dataCount, file, line);
            if (mod_mf11_lens_posn_dataDupInfo != nullptr && mod_mf11_lens_posn_dataDupInfo->Object != nullptr)
            {
                mod_mf11_lens_posn_data = (mod_mf11_lens_posn_dataType*)mod_mf11_lens_posn_dataDupInfo->Object;
                if (mod_mf11_lens_posn_data == nullptr)
                {
                    if (mod_mf11_lens_posn_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_lens_posn_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_mf11_lens_posn_dataDupInfo->File, mod_mf11_lens_posn_dataDupInfo->Line, mod_mf11_lens_posn_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_mf11_lens_posn_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_mf11_lens_posn_dataDupInfo->Line, mod_mf11_lens_posn_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_mf11_lens_posn_data == nullptr)
            {
                if (result && mod_mf11_lens_posn_dataCount > 0)
                {
                    mod_mf11_lens_posn_data = PARAMETER_NEW mod_mf11_lens_posn_dataType[mod_mf11_lens_posn_dataCount];
                    (void)pointerEntry->SetDupObject(mod_mf11_lens_posn_data, mod_mf11_lens_posn_dataCount, file, line);
                }
                if (!result || mod_mf11_lens_posn_data == nullptr)
                {
                    if (mod_mf11_lens_posn_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_mf11_lens_posn_data\n");
                    }
                    mod_mf11_lens_posn_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_mf11_lens_posn_dataCount; i++)
                {
                    result = mod_mf11_lens_posn_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_mf11_lens_posn_data == nullptr)
        {
            mod_mf11_lens_posn_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_mf11_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mfsr_disable_gain);

    SYMBOL_TABLE_ENTRY_READ(entry, result, mfsr_disable_gain, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_mf11Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_mf11_reserve);
    PARAMETER_INITIALIZE(chromatix_mf11_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = dynamic_enable_triggers.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_mf11_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_mf11_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_mfnr);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable_mfnr, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 8; i++)
    {
        result = chromatix_mf11Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::dynamic_enable_triggersStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_mfnr);

    result = enable_mfnr.Load(entry, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct_enable_mfnrStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11Type::dynamic_enable_triggersStruct::enable_mfnrStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(hyst_control_var);
    PARAMETER_INITIALIZE(hyst_mode);
    PARAMETER_INITIALIZE(hyst_trigger);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    if (result)
    {
        result = ispglobalelements::ReadEnum_control_var_type(entry, hyst_control_var, alignment);
    }
    if (result)
    {
        result = ispglobalelements::ReadEnum_hyst_direction(entry, hyst_mode, alignment);
    }
    if (result)
    {
        result = hyst_trigger.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_aec_dataType::aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_cct_data))
    {
        PARAMETER_DELETE[] mod_mf11_cct_data;
    }
    mod_mf11_cct_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_aec_dataCount; i++)
    {
        mod_mf11_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_aec_data))
    {
        PARAMETER_DELETE[] mod_mf11_aec_data;
    }
    mod_mf11_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_hdr_aec_dataCount; i++)
    {
        mod_mf11_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_mf11_hdr_aec_data;
    }
    mod_mf11_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_pre_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    pre_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_drc_gain_dataCount; i++)
    {
        mod_mf11_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_mf11_drc_gain_data;
    }
    mod_mf11_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_post_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_post_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    post_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_post_scale_ratio_dataType_post_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_post_scale_ratio_dataType::post_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_pre_scale_ratio_dataCount; i++)
    {
        mod_mf11_pre_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_pre_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_mf11_pre_scale_ratio_data;
    }
    mod_mf11_pre_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_lens_zoom_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_zoom_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_lens_zoom_dataType::lens_zoom_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_post_scale_ratio_dataCount; i++)
    {
        mod_mf11_post_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_post_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_mf11_post_scale_ratio_data;
    }
    mod_mf11_post_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_lens_posn_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_posn_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_mf11_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_mf11_lens_posn_dataType::lens_posn_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_lens_zoom_dataCount; i++)
    {
        mod_mf11_lens_zoom_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_lens_zoom_data))
    {
        PARAMETER_DELETE[] mod_mf11_lens_zoom_data;
    }
    mod_mf11_lens_zoom_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_mf11_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_mf11_lens_posn_dataCount; i++)
    {
        mod_mf11_lens_posn_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_mf11_lens_posn_data))
    {
        PARAMETER_DELETE[] mod_mf11_lens_posn_data;
    }
    mod_mf11_lens_posn_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_mf11Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_mf11_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11Type::Release()
{
    ((chromatix_mf11TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_mf11Type::GetModified()
{
    return ((chromatix_mf11TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_mf11TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_mf11TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_mf11TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_mf11TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_mf11TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_mf11TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_mf11TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_mf11TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_mf11TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_mf11TypeClass::Release()
{
    ParameterModule::Release();
}

MF_1_1_0_NAMESPACE_END
